@@ -228,13 +228,50 @@ class NaturalDeductionSystem:
 
         >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.natural_deduction import classical_natural_deduction_system
-        >>> inf = classical_parser.parse('p and q / p')
+        >>> inf = classical_parser.parse('p ∧ q / p')
         >>> deriv = classical_parser.parse_derivation('''
-        ... p and q; premise; []; []
+        ... p ∧ q; premise; []; []
         ... p; E∧; [0]; []''',
         ... natural_deduction=True)
         >>> classical_natural_deduction_system.is_correct_derivation(deriv, inf)
         True
+
+        Also note that ``on_steps`` need to be provided in the order they were specified in the rule. E.g., the
+        conditional elimination rule states:
+
+        >>> cond_elim = NaturalDeductionRule([
+        >>> '(...)',
+        >>> NaturalDeductionStep(Formula(['→', ['A'], ['B']]), open_suppositions=[]),
+        >>> '(...)',
+        >>> NaturalDeductionStep(Formula(['A']), open_suppositions=[]),
+        >>> '(...)',
+        >>> NaturalDeductionStep(Formula(['B']), 'E→', [0, 1], open_suppositions=[])
+        >>> ]),
+
+        So, if we do:
+
+        >>> from logics.utils.parsers import classical_parser
+        >>> from logics.instances.propositional.natural_deduction import classical_natural_deduction_system
+        >>> inf = classical_parser.parse('p → q, p / q')
+        >>> deriv = classical_parser.parse_derivation('''
+        ... p → q; premise; []; []
+        ... p; premise; []; []
+        ... q; E→; [1, 0]; []''',
+        ... natural_deduction=True)
+        >>> classical_natural_deduction_system.is_correct_derivation(deriv, inf)
+        False
+
+        The last step is incorrect because the conditional elimination rule specifies that the first ``on_step`` is the
+        conditional statement and the second is the antecedent.
+
+        If you want to be able to specify them in reverse order, the solution is to add another rule to the system with
+        the ``on_steps`` reversed. There are some predefined systems that do this
+        (for rules that do not involve suppositions), see the Instances below.
+
+        >>> from logics.instances.propositional.natural_deduction import classical_natural_deduction_system_unordered
+        >>> # define the same inference and derivation as in the example above
+        >>> classical_natural_deduction_system_unordered.is_correct_derivation(deriv, inf)
+        True
         """
         error_list = list()
 
@@ -247,8 +284,7 @@ class NaturalDeductionSystem:
                     if not return_error_list:
                         return False
                     else:
-                        error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_PREMISE, category="ND",
-                                                          index=step_index,
+                        error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_PREMISE, index=step_index,
                                                           description="Step was marked as 'premise', but is not a "
                                                                       "premise of the inference given"))
                         if exit_on_first_error:
@@ -259,9 +295,9 @@ class NaturalDeductionSystem:
                         if not return_error_list:
                             return False
                         else:
-                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND",
-                                                              index=0, description="Incorrect supposition handling. "
-                                                                       "Premise steps do not open suppositions"))
+                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=0,
+                                                              description="Incorrect supposition handling. Premise "
+                                                                          "steps do not open suppositions"))
                             if exit_on_first_error:
                                 return False, error_list
                 else:
@@ -269,8 +305,7 @@ class NaturalDeductionSystem:
                         if not return_error_list:
                             return False
                         else:
-                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND",
-                                                              index=step_index,
+                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=step_index,
                                                               description="Incorrect supposition handling"))
                             if exit_on_first_error:
                                 return False, error_list
@@ -283,8 +318,8 @@ class NaturalDeductionSystem:
                         if not return_error_list:
                             return False
                         else:
-                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND",
-                                                              index=0, description="Incorrect supposition handling"))
+                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=0,
+                                                              description="Incorrect supposition handling"))
                             if exit_on_first_error:
                                 return False, error_list
                 else:
@@ -294,8 +329,7 @@ class NaturalDeductionSystem:
                         if not return_error_list:
                             return False
                         else:
-                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND",
-                                                              index=step_index,
+                            error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=step_index,
                                                               description="Incorrect supposition handling"))
                             if exit_on_first_error:
                                 return False, error_list
@@ -307,8 +341,7 @@ class NaturalDeductionSystem:
                     if not return_error_list:
                         return False
                     else:
-                        error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_JUSTIFICATION, category="ND",
-                                                          index=step_index,
+                        error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_JUSTIFICATION, index=step_index,
                                                           description="Justification is incorrect, must be either "
                                                                       "'premise', 'supposition', or the name of a "
                                                                       "specific axiom or rule"))
@@ -348,7 +381,7 @@ class NaturalDeductionSystem:
                             else:
                                 # If there is more than one possible rule, return a generic error message
                                 error_list.append(CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                                  category="ND", index=step_index,
+                                                                  index=step_index,
                                                                   description="Incorrect application of rule"))
                             if exit_on_first_error:
                                     return False, error_list
@@ -358,8 +391,7 @@ class NaturalDeductionSystem:
             if not return_error_list:
                 return False
             else:
-                error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_CONCLUSION, category="ND",
-                                                  index=len(derivation)-1,
+                error_list.append(CorrectionError(code=ErrorCode.ND_INCORRECT_CONCLUSION, index=len(derivation)-1,
                                                   description="Final step of the derivation is not the conclusion "
                                                               "of the inference"))
                 if exit_on_first_error:
@@ -416,7 +448,7 @@ class NaturalDeductionSystem:
         if len(last_step.on_steps) != len(rule) - 1:
             if not return_error:
                 return False
-            return False, CorrectionError(code=ErrorCode.ND_INCORRECT_ON_STEPS, category="ND", index=step,
+            return False, CorrectionError(code=ErrorCode.ND_INCORRECT_ON_STEPS, index=step,
                                           description="Number of on steps given are not equal to the number of rule "
                                                       "premises")
 
@@ -425,7 +457,7 @@ class NaturalDeductionSystem:
             if on_step >= len(derivation) - 1:
                 if not return_error:
                     return False
-                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_ON_STEPS, category="ND", index=step,
+                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_ON_STEPS, index=step,
                                               description=f"On step {on_step} is greater or equal than the current "
                                                           f"step, must be lower")
 
@@ -439,7 +471,7 @@ class NaturalDeductionSystem:
             if not exact_match and not without_num_match:
                 if not return_error:
                     return False
-                return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, category="ND", index=step,
+                return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                               description=f"Justification for step {derivation.index(last_step)} does "
                                                           f"not coincide with the justification in the rule conclusion")
         # (content)
@@ -447,7 +479,7 @@ class NaturalDeductionSystem:
         if not instance:
             if not return_error:
                 return False
-            return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, category="ND", index=step,
+            return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                           description=f"Step {derivation.index(last_step)} is not an instance of the "
                                                       f"conclusion of the rule given")
 
@@ -478,8 +510,7 @@ class NaturalDeductionSystem:
                 if prev_step is not None and step_number != prev_step + 1:
                     if not return_error:
                         return False
-                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                  category="ND", index=step,
+                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                                   description=f"On step {step_number} does not immediately follow the "
                                                               f"previous on step, as the rule requires")
 
@@ -489,8 +520,7 @@ class NaturalDeductionSystem:
                         derivation[step_number].justification != rule_step.justification:
                     if not return_error:
                         return False
-                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                  category="ND", index=step,
+                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                                   description=f"Justification for on step {step_number} does not "
                                                               f"coincide with the justification in rule "
                                                               f"premise {prem_number}")
@@ -503,8 +533,7 @@ class NaturalDeductionSystem:
                 if not instance:
                     if not return_error:
                         return False
-                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                  category="ND", index=step,
+                    return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                                   description=f"On step {step_number} is not an instance of rule "
                                                               f"premise number {prem_number}")
                 else:
@@ -525,8 +554,7 @@ class NaturalDeductionSystem:
                             relevant_sup_dict[relevant_step] not in derivation[step_number].open_suppositions:
                         if not return_error:
                             return False
-                        return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                      category="ND", index=step,
+                        return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                                       description=f"Incorrect use of suppositions in 'on step' "
                                                                   f"{step_number}")
                     # Check that closed suppositions of the rule are not open in the derivation
@@ -534,8 +562,7 @@ class NaturalDeductionSystem:
                             relevant_sup_dict[relevant_step] in derivation[step_number].open_suppositions:
                         if not return_error:
                             return False
-                        return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED,
-                                                      category="ND", index=step,
+                        return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                                       description=f"Incorrect use of suppositions in 'on step' "
                                                                   f"{step_number}")
 
@@ -547,15 +574,14 @@ class NaturalDeductionSystem:
                         if open_sup not in last_step.open_suppositions:
                             if not return_error:
                                 return False
-                            return False, CorrectionError(code=ErrorCode.ND_CLOSED_SUPPOSITION,
-                                                          category="ND", index=step,
+                            return False, CorrectionError(code=ErrorCode.ND_CLOSED_SUPPOSITION, index=step,
                                                           description=f"Step {step_number} is in a closed supposition")
 
         # Conclusion again (check that it immediately follows the last step, if it corresponds)
         if prev_step is not None and derivation.index(last_step) != prev_step + 1:
             if not return_error:
                 return False
-            return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, category="ND", index=step,
+            return False, CorrectionError(code=ErrorCode.ND_RULE_INCORRECTLY_APPLIED, index=step,
                                           description=f"On step {derivation.index(last_step)} does not immediately "
                                                       f"follow the previous on step, as the rule requires")
 
@@ -565,13 +591,13 @@ class NaturalDeductionSystem:
                     relevant_sup_dict[relevant_step] not in last_step.open_suppositions:
                 if not return_error:
                     return False
-                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND", index=step,
+                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=step,
                                               description="Incorrect supposition handling")
             if relevant_step not in rule[-1].open_suppositions and \
                     relevant_sup_dict[relevant_step] in last_step.open_suppositions:
                 if not return_error:
                     return False
-                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND", index=step,
+                return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=step,
                                               description="Incorrect supposition handling")
         # Outside the rule suppositions, every supposition present in the previous step must still be open,
         # and vice versa (the conclusion step should not open any new suppositions not allowed by the rule)
@@ -579,7 +605,7 @@ class NaturalDeductionSystem:
                 [s2 for s2 in derivation[step].open_suppositions if s2 not in relevant_sup_dict.values()]:
             if not return_error:
                 return False
-            return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, category="ND", index=step,
+            return False, CorrectionError(code=ErrorCode.ND_INCORRECT_SUPPOSITION, index=step,
                                           description="Incorrect supposition handling")
 
         # If it got to here and did not return, the application is correct
